# vs-aa

### VapourSynth anti aliasing and scaling functions
<br>

Wrappers for aa/scaling plugins and functions, aimed to have compatibility with vs-kernels scalers.

You can find support in the [IEW Discord server](https://discord.gg/qxTxVJGtst).
<br><br>
## How to install

Install `vsaa` with the following command:

```sh
$ pip install vsaa
```

Or if you want the latest git version, install it with this command:

```sh
$ pip install git+https://github.com/Irrational-Encoding-Wizardry/vs-aa.git
```
